@@ -1,5 +1,5 @@
 import pymysql
-from sql import SQL
+from zmysql.sql import SQL
 
 
 class Mysql:
